summaryrefslogtreecommitdiff
path: root/src/linux/up-device-hid.c
diff options
context:
space:
mode:
authorRichard Hughes <richard@hughsie.com>2010-01-18 13:20:36 +0000
committerRichard Hughes <richard@hughsie.com>2010-01-18 13:20:36 +0000
commitbc928f7ae8b88d05ed648b62176c0ba25c8e5770 (patch)
tree48516d8209dee37818804bbbff8989902c8c0d94 /src/linux/up-device-hid.c
parentc8cec18f064f5cb86896e6ff17d96d73fb9fd0dc (diff)
downloadupower-bc928f7ae8b88d05ed648b62176c0ba25c8e5770.tar.gz
trivial: switch to using the new udev attribute names (no ABI or API break)
Diffstat (limited to 'src/linux/up-device-hid.c')
-rw-r--r--src/linux/up-device-hid.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/linux/up-device-hid.c b/src/linux/up-device-hid.c
index 8c43521..60a6b52 100644
--- a/src/linux/up-device-hid.c
+++ b/src/linux/up-device-hid.c
@@ -314,7 +314,7 @@ up_device_hid_coldplug (UpDevice *device)
/* detect what kind of device we are */
native = G_UDEV_DEVICE (up_device_get_native (device));
- type = g_udev_device_get_property (native, "DKP_BATTERY_TYPE");
+ type = g_udev_device_get_property (native, "UPOWER_BATTERY_TYPE");
if (type == NULL || g_strcmp0 (type, "ups") != 0)
goto out;
@@ -340,8 +340,8 @@ up_device_hid_coldplug (UpDevice *device)
goto out;
}
- /* prefer DKP names */
- vendor = g_udev_device_get_property (native, "DKP_VENDOR");
+ /* prefer UPOWER names */
+ vendor = g_udev_device_get_property (native, "UPOWER_VENDOR");
if (vendor == NULL)
vendor = g_udev_device_get_property (native, "ID_VENDOR");